package main

import androidx.compose.foundation.*
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.lazy.rememberLazyListState
import androidx.compose.material.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp

var mostUsedWordList = mutableMapOf<String, Int>()

enum class Language {
    FRENCH, ENGLISH
}

@Composable
fun homePage(
    languageManager: LanguageManager,
    onGlossaryClick: () -> Unit,
    onCodeToVerifyClick: () -> Unit
) {
    val noFileSnackbarVisibleState = remember { mutableStateOf(false) }
    var isCompareClicked by remember { mutableStateOf(false) }

    var selectedGlossary by remember { mutableStateOf<Glossary?>(null) }

    if (!isCompareClicked && selectedGlossary == null) {
        // Utilisez un Box pour placer le drapeau en haut à droite
        Box(
            modifier = Modifier
                .fillMaxSize()
                .padding(16.dp),
            contentAlignment = Alignment.TopEnd
        ) {
            // Utilisez les images des drapeaux
            Image(
                painter = painterResource(if (languageManager.currentLanguage == Language.FRENCH) "FR.png" else "EN.png"),
                contentDescription = "Language Flag",
                modifier = Modifier.size(48.dp)
                    .clickable { languageManager.changeLanguage() }
            )
        }

        Column(
            modifier = Modifier.fillMaxSize(),
            verticalArrangement = Arrangement.Center,
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Text("Quali'Nomme", style = MaterialTheme.typography.h3)

            Spacer(modifier = Modifier.height(16.dp))

            Column {
                Row(
                    horizontalArrangement = Arrangement.spacedBy(16.dp)
                ) {
                    Button(
                        onClick = onGlossaryClick,
                        modifier = Modifier.width(200.dp),
                        colors = ButtonDefaults.buttonColors(
                            backgroundColor = customRedColor,
                            contentColor = Color.White
                        )
                    ) {
                        Text(languageManager.getGlossaryText())
                    }

                    Button(
                        onClick = onCodeToVerifyClick,
                        modifier = Modifier.width(200.dp),
                        colors = ButtonDefaults.buttonColors(
                            backgroundColor = customRedColor,
                            contentColor = Color.White
                        )
                    ) {
                        Text(languageManager.getCodeToVerifyText())
                    }

                    Button(
                        onClick = {
                            if (mostUsedWordList.isEmpty()) {
                                noFileSnackbarVisibleState.value = true
                                println("Veuillez d'abord importer un fichier")
                                return@Button
                            } else {
                                isCompareClicked = true
                            }
                        },
                        modifier = Modifier.width(200.dp),
                        colors = ButtonDefaults.buttonColors(
                            backgroundColor = customRedColor,
                            contentColor = Color.White
                        ),
                        enabled = mostUsedWordList.isNotEmpty()
                    ) {
                        Text(languageManager.getCompareText())
                    }
                }
            }

            if (noFileSnackbarVisibleState.value) {
                Snackbar(
                    modifier = Modifier.padding(16.dp),
                    action = {
                        Button(
                            onClick = { noFileSnackbarVisibleState.value = false },
                            colors = ButtonDefaults.buttonColors(
                                backgroundColor = customRedColor,
                                contentColor = Color.White
                            )
                        ) {
                            Text("OK")
                        }
                    }
                ) {
                    Text("Veuillez d'abord importer un fichier")
                }
            }
        }
    }

    if (isCompareClicked && selectedGlossary == null) {
        GlossaryList(glossaries = loadGlossaries()) { glossary ->
            selectedGlossary = glossary
        }
    } else if (isCompareClicked) {
        selectedGlossary?.let {
            compareResults(
                glossaryWords = loadDatasFromFile(it.jsonFilePath),
                codeWords = mostUsedWordList.keys.toList(),
                onBackClick = { isCompareClicked = false; selectedGlossary = null }
            )
        }
    }
}

@Composable
fun GlossaryList(glossaries: List<Glossary>, onGlossarySelected: (Glossary) -> Unit) {
    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text("Sélectionnez un glossaire", style = MaterialTheme.typography.h5)

        Spacer(modifier = Modifier.height(16.dp))

        Box(
            modifier = Modifier
                .height(500.dp)
                .padding(10.dp)
        ) {
            val scrollState = rememberLazyListState()
            LazyColumn(
                state = scrollState,
                modifier = Modifier.padding(10.dp).border(1.dp, Color.Black),
                verticalArrangement = Arrangement.spacedBy(10.dp)
            ) {
                items(glossaries) { glossary ->
                    Row(
                        modifier = Modifier.width(200.dp).fillMaxWidth(),
                        horizontalArrangement = Arrangement.SpaceBetween
                    ) {
                        Button(
                            onClick = {
                                onGlossarySelected(glossary)
                            },
                            modifier = Modifier
                                .width(150.dp)
                                .padding(10.dp, 0.dp, 0.dp, 0.dp),
                            colors = ButtonDefaults.buttonColors(
                                backgroundColor = customRedColor,
                                contentColor = Color.White
                            )
                        ) {
                            Text(glossary.name)
                        }
                    }
                }
            }
            VerticalScrollbar(
                modifier = Modifier.align(Alignment.CenterEnd).fillMaxHeight(),
                adapter = rememberScrollbarAdapter(scrollState)
            )
            Spacer(modifier = Modifier.height(6.dp))
        }
    }
}
